using System;
using System.ComponentModel;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml.Serialization;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;
using Microsoft.SharePoint.WebPartPages;

namespace ReflectionIT.SharePoint.WebParts
{
	/// <summary>
	/// Description for UserControlContainer.
	/// </summary>
	[DefaultProperty("Text"),
		ToolboxData("<{0}:UserControlContainer runat=server></{0}:UserControlContainer>"),
		XmlRoot(Namespace="ReflectionIT.SharePoint.WebParts")]
	public class UserControlContainer : Microsoft.SharePoint.WebPartPages.WebPart
	{
		private const string defaultText = "";
		private string _userControl = defaultText;
		private Control _control = null;

		[Browsable(true),
			Category("User Control"),
			DefaultValue(defaultText),
			WebPartStorage(Storage.Personal),
			FriendlyName("User Control (.ascx)"),
			Description("Path to the User Control (.ascx)")]
		public string UserControl
		{
			get
			{
				return _userControl;
			}

			set
			{
				_userControl = value;
			}
		}
		
		/// <summary>
		///	This method gets the custom tool parts for this Web Part by overriding the
		///	GetToolParts method of the WebPart base class. You must implement
		///	custom tool parts in a separate class that derives from 
		///	Microsoft.SharePoint.WebPartPages.ToolPart. 
		///	</summary>
		///<returns>An array of references to ToolPart objects.</returns>
		public override ToolPart[] GetToolParts() {
			ToolPart[] toolparts = new ToolPart[3];
			WebPartToolPart wptp = new WebPartToolPart();
			CustomPropertyToolPart custom = new CustomPropertyToolPart();
			toolparts[0] = custom;
			toolparts[1] = wptp;
			toolparts[2] = new CopyrightToolpart();

			wptp.Expand(Microsoft.SharePoint.WebPartPages.WebPartToolPart.Categories.Appearance);
			custom.Expand("User Control");

			return toolparts;
		}

		/// <summary>
		/// Load the UserControl
		/// </summary>
		protected override void CreateChildControls() {
			base.CreateChildControls ();

			try {
				if (_userControl != defaultText) {
					_control = this.Page.LoadControl(_userControl);
				} else {
					_control = new LiteralControl(string.Format("To link to content, <a href=\"javascript:MSOTlPn_ShowToolPaneWrapper('{0}','{1}','{2}');\">open the tool pane</a> and then type a URL in the Link text box.", 1, 129, this.ID));
				}
			} catch (System.Exception ex) {
				_control = new LiteralControl(string.Format("<b>Error:</b> unable to load {0}<br /><b>Details:</b> {1}", _userControl, ex.Message));
			}
			
			if (_control != null) {
				// Add to the Controls collection to support postback
				this.Controls.Add(_control);
			}
		}

		
		/// <summary>
		/// Render this Web Part to the output parameter specified.
		/// </summary>
		/// <param name="output"> The HTML writer to write out to </param>
		protected override void RenderWebPart(HtmlTextWriter output)
		{
			EnsureChildControls();
			if (_control != null) {
				_control.RenderControl(output);
			}
		}
	}
}
